#
# spec file for package python-Pweave
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
%define         skip_python36 1
Name:           python-Pweave
Version:        0.30.3
Release:        6.5
Summary:        Scientific reports with embedded python computations
License:        BSD-3-Clause
URL:            https://github.com/mpastell/Pweave
Source:         https://files.pythonhosted.org/packages/source/P/Pweave/Pweave-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/mpastell/Pweave/pull/167 Adjust for API changes in Python-Markdown 3.0
Patch0:         markdown.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Markdown
Requires:       python-Pygments
Requires:       python-certifi
Requires:       python-jupyter_client
Requires:       python-jupyter_ipykernel
Requires:       python-jupyter_ipython
Requires:       python-jupyter_nbconvert
Requires:       python-jupyter_nbformat
Recommends:     python-Sphinx
Recommends:     python-matplotlib
Recommends:     python-scipy
Recommends:     python-sphinx_rtd_theme
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Markdown}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module jupyter_client}
BuildRequires:  %{python_module jupyter_ipykernel}
BuildRequires:  %{python_module jupyter_ipython}
BuildRequires:  %{python_module jupyter_nbconvert}
BuildRequires:  %{python_module jupyter_nbformat}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
# /SECTION
%python_subpackages

%description
Pweave is a scientific report generator and a literate programming
tool for Python. Pweave can capture the results and plots from data
analysis and works well with NumPy, SciPy and matplotlib. It is able
to run python code from source document and include the results and
capture matplotlib plots in the output.

Pweave is good for creating reports, tutorials, presentations etc.
with embedded python code It can also be used to make websites together
with e.g. Sphinx or rest2web.

%prep
%setup -q -n Pweave-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/pweave
%python_clone -a %{buildroot}%{_bindir}/ptangle
%python_clone -a %{buildroot}%{_bindir}/pypublish
%python_clone -a %{buildroot}%{_bindir}/pweave-convert

%post
%python_install_alternative pweave
%python_install_alternative ptangle
%python_install_alternative pypublish
%python_install_alternative pweave-convert

%postun
%python_uninstall_alternative pweave
%python_uninstall_alternative ptangle
%python_uninstall_alternative pypublish
%python_uninstall_alternative pweave-convert

%check
# tests.test_readers.test_url - online
# Formatters/publish Layout changes with updates in jupyter
# Failing test for testFIR_FilterExampleTex is gh#mpastell/Pweave#168
%pytest -k 'not (test_url or testFormatters or test_publish or testFIR_FilterExampleTex)'

%files %{python_files}
%doc CHANGELOG.txt README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/pweave
%python_alternative %{_bindir}/ptangle
%python_alternative %{_bindir}/pypublish
%python_alternative %{_bindir}/pweave-convert
%{python_sitelib}/*

%changelog
* Sat Oct 15 2022 Matej Cepl <mcepl@suse.com>
- Skip failing test testFIR_FilterExampleTex (gh#mpastell/Pweave#168)
* Thu Oct  6 2022 Markéta Machová <mmachova@suse.com>
- Add markdown.patch to fix the tests
* Fri Feb 12 2021 Dirk Müller <dmueller@suse.com>
- skip python 36 build (scipy)
* Tue Feb  2 2021 Dirk Müller <dmueller@suse.com>
- update-alternatives for multi-python3 builds
* Mon Jun  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Adjust the tests to run with pytest and not nose
- Skip format checking tests that rely on jupyter behaviour
  and thus break with updates
* Wed Sep 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip one more test that fails due to extra output from
  new matplotlib:
  * testFIR_FilterExampleTex
* Tue Mar  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update 0.30.3:
  * no upstream changelog for this release
- Run tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Sep 12 2017 toddrme2178@gmail.com
- Initial version
